EBeam library
==============

.. automodule:: opics.libs.ebeam
   :inherited-members:
   :exclude-members: get_data, interpolate_sparameters, load_sparameters, plot_sparameters, write_sparameters
   :no-undoc-members:
   :show-inheritance: